import { useRequest } from "ahooks";
import React, { useState } from "react";
import styles from "./index.less";
import ReactECharts from "echarts-for-react";
import { createFromIconfontCN } from "@ant-design/icons";
import * as echarts from "echarts";
import { Button } from "antd";
import "echarts/lib/component/graphic";
import { ScrollBoard } from "@jiaminghi/data-view-react";
import Threedire from "./threedire";
import { doFetch } from "@/utils/doFetch";

const IconFont = createFromIconfontCN({
  scriptUrl: "//at.alicdn.com/t/c/font_3649650_01jk3haanj83.js",
});

const Item = ({ title, children }) => {
  return (
    <div className={styles.item}>
      <p className={styles?.title}>
        <IconFont
          type="icon-lingxing"
          style={{ fontSize: 12, marginRight: 10 }}
        />
        {title}
      </p>

      {children}
    </div>
  );
};

export default function HomePage() {
  const leftone = useRequest(
    async () => {
      //format result
      let res = await doFetch({
          url: "/ngic-statistics/deviceStatus/queryEquipmentStatusChart",
          params: {},
        }),
        result = res?.data?.dataList ?? [];
      return result;
    },
    {
      refreshDeps: [],
    }
  );


  return (
    <div className={styles?.container}>
      <div className={styles?.left}>
        <Item title={"设备状态"}>
          <ReactECharts
            style={{ width: "100%", height: "100%", marginTop: 0 }}
            option={{
              legend: {
                orient: "vertical", //垂直显示
                y: "center", //延Y轴居中
                x: "right", //居右显示
                padding: 20, //调节legend的位置
                textStyle: {
                  fontSize: 14, //字体大小
                  color: "#ffffff", //字体颜色
                },
                icon: "circle",
              },
              tooltip: {
                trigger: "item",
              },
              color:["#6AE49B","#4887E0","#8D8D8D","#F31A1A"],
              series: [
                {
                  name: "设备状态",
                  type: "pie",
                  radius: [8, 100],
                  center: ["34%", "50%"],
                  itemStyle: {
                    borderRadius: 8,
                  },
                  label: {
                    show: false,
                  },
                  data: leftone.data,
                },
              ],
            }}
            notMerge={true}
            lazyUpdate={true}
            theme={"theme_name"}
          />
        </Item>
        <Item title={"生产统计"}>
          <ReactECharts
            style={{ width: "100%", height: "100%", marginTop: -28 }}
            option={{
              xAxis: {
                data: [
                  "点",
                  "击",
                  "柱",
                  "子",
                  "或",
                  "者",
                  "两",
                  "指",
                  "在",
                  "触",
                  "屏",
                  "上",
                  "滑",
                  "动",
                  "能",
                  "够",
                  "自",
                  "动",
                  "缩",
                  "放",
                ],
                splitLine: {
                  show: false,
                },
                axisLabel: {
                  color: "#bbbbbb",
                },
                axisTick: {
                  show: false,
                },
                axisLine: {
                  show: false,
                },
                z: 10,
              },
              yAxis: {
                axisLine: {
                  show: false,
                },
                axisTick: {
                  show: false,
                },
                axisLabel: {
                  color: "#bbbbbb",
                  show: true,
                  formatter: "{value}件",
                },
                splitLine: {
                  lineStyle: {
                    color: ["rgba(255,255,255,0.2)"],
                    type: "solid",
                  },
                },
              },
              dataZoom: [
                {
                  type: "inside",
                },
              ],
              tooltip: {
                trigger: "item",
              },
              grid: {
                top: "58px",
                left: "12px",
                right: "5%",
                bottom: "28px",
                containLabel: true,
              },
              series: [
                {
                  type: "bar",
                  itemStyle: {
                    color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                      { offset: 0, color: "rgba(106,228,155,0.4)" },
                      { offset: 0.2, color: "rgba(106,228,155,0.2)" },
                      { offset: 1, color: "rgba(106,228,155,0)" },
                    ]),
                    borderWidth: 1,
                    borderColor: "#64DB9B",
                  },
                  // emphasis: {
                  //   itemStyle: {
                  //     color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                  //       { offset: 0, color: "#2378f7" },
                  //       { offset: 0.7, color: "#2378f7" },
                  //       { offset: 1, color: "#83bff6" },
                  //     ]),
                  //   },
                  // },
                  data: [
                    220, 182, 191, 234, 290, 330, 310, 123, 442, 321, 90, 149,
                    210, 122, 133, 334, 198, 123, 125, 220,
                  ],
                },
              ],
            }}
            notMerge={true}
            lazyUpdate={true}
            theme={"theme_name"}
          />
        </Item>
        <Item title={"车间利用率"}>
          <ReactECharts
            style={{ width: "100%", height: "100%", marginTop: -28 }}
            option={{
              xAxis: {
                axisLabel: {
                  color: "#bbbbbb",
                },
                type: "category",
                boundaryGap: false,
                data: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
              },
              grid: {
                top: "58px",
                left: "12px",
                right: "5%",
                bottom: "28px",
                containLabel: true,
              },
              yAxis: {
                type: "value",
                axisLabel: {
                  color: "#bbbbbb",
                  show: true,
                  formatter: "{value}%",
                },
                splitLine: {
                  lineStyle: {
                    color: ["rgba(255,255,255,0.2)"],
                    type: "solid",
                  },
                },
              },
              series: [
                {
                  data: [820, 932, 901, 934, 1290, 1330, 1320],
                  type: "line",
                  lineStyle: {
                    color: "rgba(72, 135, 244,0.4)",
                    width: 1,
                    type: "dashed",
                  },
                  areaStyle: {
                    color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                      {
                        offset: 0,
                        color: "rgba(72, 135, 244,0.4)",
                      },
                      {
                        offset: 1,
                        color: "rgba(72, 135, 244,0)",
                      },
                    ]),
                  },
                },
              ],
            }}
            notMerge={true}
            lazyUpdate={true}
            theme={"theme_name"}
          />
        </Item>
      </div>
      <div className={styles?.bac}>
        <Threedire></Threedire>
      </div>

      <div className={styles?.right}>
        <Item title={"告警信息"}>
          <div style={{ padding: "0 18px" }}>
            <ScrollBoard
              config={{
                headerBGC: "tranparent",
                oddRowBGC: "tranparent",
                evenRowBGC: "tranparent",
                header: ["告警时间", "严重程度", "设备名称", "告警信息"],
                data: [
                  ["行1列1", "行1列2", "行1列3", "行1列3"],
                  ["行2列1", "行2列2", "行2列3", "行1列3"],
                  ["行3列1", "行3列2", "行3列3", "行1列3"],
                  ["行4列1", "行4列2", "行4列3", "行1列3"],
                  ["行5列1", "行5列2", "行5列3", "行1列3"],
                  ["行6列1", "行6列2", "行6列3", "行1列3"],
                  ["行7列1", "行7列2", "行7列3", "行1列3"],
                  ["行8列1", "行8列2", "行8列3", "行1列3"],
                  ["行9列1", "行9列2", "行9列3", "行1列3"],
                  ["行10列1", "行10列2", "行10列3", "行1列3"],
                ],
                rowNum: 6,
              }}
              style={{ width: "100%", height: "100%" }}
            />
          </div>
        </Item>
        <Item title={"用电量"}>
          <ReactECharts
            style={{ width: "100%", height: "100%", marginTop: -28 }}
            option={{
              xAxis: {
                data: [
                  "点",
                  "击",
                  "柱",
                  "子",
                  "或",
                  "者",
                  "两",
                  "指",
                  "在",
                  "触",
                  "屏",
                  "上",
                  "滑",
                  "动",
                  "能",
                  "够",
                  "自",
                  "动",
                  "缩",
                  "放",
                ],
                splitLine: {
                  show: false,
                },
                axisLabel: {
                  color: "#bbbbbb",
                },
                axisTick: {
                  show: false,
                },
                axisLine: {
                  show: false,
                },
                z: 10,
              },
              yAxis: {
                axisLine: {
                  show: false,
                },
                axisTick: {
                  show: false,
                },
                axisLabel: {
                  color: "#bbbbbb",
                  show: true,
                  formatter: "{value}件",
                },
                splitLine: {
                  lineStyle: {
                    color: ["rgba(255,255,255,0.2)"],
                    type: "solid",
                  },
                },
              },
              dataZoom: [
                {
                  type: "inside",
                },
              ],
              tooltip: {
                trigger: "item",
              },
              grid: {
                top: "58px",
                left: "12px",
                right: "5%",
                bottom: "28px",
                containLabel: true,
              },
              series: [
                {
                  type: "bar",
                  itemStyle: {
                    color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                      { offset: 0, color: "rgba(72,135,244,0.8)" },
                      { offset: 0.2, color: "rgba(72,135,244,0.4)" },
                      { offset: 1, color: "rgba(72,135,244,0)" },
                    ]),
                  },
                  // emphasis: {
                  //   itemStyle: {
                  //     color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                  //       { offset: 0, color: "#2378f7" },
                  //       { offset: 0.7, color: "#2378f7" },
                  //       { offset: 1, color: "#83bff6" },
                  //     ]),
                  //   },
                  // },
                  data: [
                    220, 182, 191, 234, 290, 330, 310, 123, 442, 321, 90, 149,
                    210, 122, 133, 334, 198, 123, 125, 220,
                  ],
                },
              ],
            }}
            notMerge={true}
            lazyUpdate={true}
            theme={"theme_name"}
          />
        </Item>
        <Item title={"故障统计"}>
          <ReactECharts
            style={{ width: "100%", height: "100%", marginTop: -28 }}
            option={{
              xAxis: {
                axisLabel: {
                  color: "#bbbbbb",
                },
                type: "category",
                boundaryGap: false,
                data: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
              },
              grid: {
                top: "58px",
                left: "12px",
                right: "5%",
                bottom: "28px",
                containLabel: true,
              },
              yAxis: {
                type: "value",
                axisLabel: {
                  color: "#bbbbbb",
                  show: true,
                  formatter: "{value}%",
                },
                splitLine: {
                  lineStyle: {
                    color: ["rgba(255,255,255,0.2)"],
                    type: "solid",
                  },
                },
              },
              series: [
                {
                  data: [820, 932, 901, 934, 1290, 1330, 10],
                  type: "line",
                  lineStyle: {
                    color: "rgba(243, 26, 25,0.4)",
                    width: 1,
                    type: "dashed",
                  },
                  itemStyle: {
                    borderColor: "rgba(243, 26, 25)",
                    color: "rgba(243, 26, 25)",
                  },
                  areaStyle: {
                    color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                      {
                        offset: 0,
                        color: "rgba(243, 26, 25,0.4)",
                      },
                      {
                        offset: 1,
                        color: "rgba(243, 26, 25,0)",
                      },
                    ]),
                  },
                },
              ],
            }}
            notMerge={true}
            lazyUpdate={true}
            theme={"theme_name"}
          />
        </Item>
      </div>
    </div>
  );
}
