/* eslint-disable array-callback-return */
/* eslint-disable no-unused-vars */
import * as THREE from "three";
import {
  Canvas,
  useFrame,
  extend,
  useLoader,
  useThree,
  axesHelper,
} from "react-three-fiber";
import { useRef, Suspense, useState, useEffect } from "react";
import {
  OrbitControls,
  Text,
  Html,
  Line,
  Points,
  Point,
  Image,
  Environment,
  useGLTF,
  PerspectiveCamera,
} from "@react-three/drei";
import { GLTFLoader } from "three/examples/jsm/loaders/GLTFLoader";
import { useWebSocket, useFullscreen, useThrottle, useRequest } from "ahooks";
import { ShrinkOutlined, ArrowsAltOutlined } from "@ant-design/icons";
import { Tooltip, notification } from "antd";
import qs from "query-string";
import Model from "./models/gltf";
import Robot from "./models";
import Jixiebi from "./models/jiqiebi";
import { doFetch } from "../utils/doFetch";

const modelconfig = [
  {
    name: "0",
    position: [-24, 0, 24],
    status: 1,
    modelname: "cqg",
    scale: 0.035,
  },
  {
    name: "1",
    position: [-21.5, 0, 24],
    status: 1,
    modelname: "kyj",
  },
  {
    name: "2",
    position: [-21.5, 0, 25.5],
    status: 1,
    modelname: "lgj",
    scale: 0.06,
  },
  {
    name: "3",
    position: [-19, 0, 15],
    status: 1,
    modelname: "ptwymc",
    rotation: [0, 1.6, 0],
  },
  {
    name: "4",
    position: [-21, 0, 6.5],
    status: 1,
    modelname: "pmmc",
    scale: 0.06,
  },
  {
    name: "5",
    position: [-21, 0, -12],
    status: 1,
    modelname: "M1.4",
  },
  {
    name: "6",
    position: [-21, 0, -4],
    status: 1,
    modelname: "M1.4",
  },
  {
    name: "7",
    position: [-21, 0, -22],
    status: 1,
    modelname: "M8",
    rotation: [0, 1.6, 0],
  },
  {
    name: "8",
    position: [-6, 0, -22],
    status: 1,
    modelname: "M8",
    rotation: [0, 1.6, 0],
  },
  {
    name: "9",
    position: [3, 0, -22],
    status: 1,
    modelname: "M8",
    rotation: [0, 1.6, 0],
  },
  {
    name: "10",
    position: [12, 0, -22],
    status: 1,
    modelname: "M8",
    rotation: [0, 1.6, 0],
  },
  {
    name: "11",
    position: [21, 0, -22],
    status: 1,
    modelname: "M8",
    rotation: [0, 1.6, 0],
  },
  {
    name: "12",
    position: [18, 0, -20.5],
    status: 1,
    modelname: "T360",
    scale: 0.75,
  },
  {
    name: "13",
    position: [5.7, 0, -7],
    status: 1,
    modelname: "T360",
    scale: 0.75,
    rotation: [0, 1.6, 0],
  },
  {
    name: "14",
    position: [19.8, 0, 8],
    status: 1,
    modelname: "M850",
    scale: 0.052,
    rotation: [0, 1.58, 0],
  },
  {
    name: "15",
    position: [18, 0, 17],
    status: 1,
    modelname: "M8",
  },
  {
    name: "16",
    position: [18, 0, 25],
    status: 1,
    modelname: "M8",
  },
  {
    name: "17",
    position: [11, 0, 26],
    status: 1,
    modelname: "M1.4",
  },
  {
    name: "18",
    position: [16.5, 0, 18.5],
    status: 1,
    modelname: "T360",
    scale: 0.75,
    rotation: [0, -1.58, 0],
  },
  {
    name: "19",
    position: [11, 0, 8],
    status: 1,
    modelname: "M850",
    scale: 0.052,
    rotation: [0, -1.58, 0],
  },
  {
    name: "20",
    position: [-2, 0, 9.2],
    status: 1,
    modelname: "T3.4",
    scale: 0.23,
    rotation: [0, 1.58, 0],
  },
  {
    name: "21",
    position: [-0.5, 0, 26],
    status: 1,
    modelname: "M1.4",
  },
  {
    name: "22",
    position: [-9, 0, 24.5],
    status: 1,
    modelname: "CAK5085",
    rotation: [0, -1.58, 0],
    scale: 0.04,
  },
  {
    name: "23",
    position: [-9, 0, 16.6],
    status: 1,
    modelname: "wyjmmc",
    rotation: [0, -1.58, 0],
    scale: 0.055,
  },
  {
    name: "24",
    position: [-8.79, 0, 8],
    status: 1,
    modelname: "nymc",
    rotation: [0, -1.58, 0],
    scale: 0.055,
  },
];

const Floor = (props) => {
  return (
    <>
      <mesh position={props.position} receiveShadow>
        <boxBufferGeometry args={[60, 0.1, 60]} />
        <meshPhysicalMaterial color={"#12284A"} />
      </mesh>
    </>
  );
};

const Bulb = (props) => {
  return (
    <mesh {...props}>
      <pointLight castShadow></pointLight>
      <ambientLight color={"#999999"}></ambientLight>
      {/* <sphereBufferGeometry args={[0.2, 60, 60]} />
      <meshPhongMaterial emissive={"yellow"} /> */}
    </mesh>
  );
};

function Threedire() {
  const texture = useLoader(THREE.TextureLoader, require("@/assets/floor.png"));

  const [config, setconfig] = useState(modelconfig);
  const { data } = useRequest(
    async () => {
      //format result
      let res = await doFetch({
          url: "/ngic-statistics/deviceStatus/queryEquipmentStatus",
          params: {},
        }),
        result = res?.data?.data ?? {};
      return result;
    },
    {
      refreshDeps: [],
    }
  );

  useEffect(() => {
    if (data) {
      setconfig((s) => {
        let news = JSON.parse(JSON.stringify(s ?? {}));
        news = news.map((it) => {
          it.status = it.name == "0" ? 1 : data[it.name];
          return it;
        });
        return news;
      });
    }
  }, [data]);

  return (
    <Canvas
      shadows
      camera={{
        position: [0, 30, 20],
      }}
    >
      {config?.map((it, i) => {
        return <Model key={it.name} {...it} />;
      })}
      <Robot />
      <Jixiebi />

      <Floor position={[2, -0.06, 0]} />
      <gridHelper args={[60, 15, "#20293A", "#20293A"]} position={[2, 0, 0]} />
      <Bulb position={[0, 6, 0]} />
      <OrbitControls />
      <>
        <mesh position={[7.5, 0, 1.4]} receiveShadow>
          <boxBufferGeometry args={[45, 0.1, 4]} />
          <meshPhysicalMaterial
            color={"green"}
            roughness={0.5}
            transmission={0.5}
          />
        </mesh>
        <mesh position={[6, 0, 15]} receiveShadow>
          <boxBufferGeometry args={[4, 0.1, 30]} />
          <meshPhysicalMaterial
            color={"green"}
            roughness={0.5}
            transmission={0.5}
          />
        </mesh>
        <mesh position={[-15, 0, 0]} receiveShadow>
          <boxBufferGeometry args={[4, 0.1, 60]} />
          <meshPhysicalMaterial
            color={"green"}
            roughness={0.5}
            transmission={0.5}
          />
        </mesh>
        <mesh position={[28, 0, 0]} receiveShadow>
          <boxBufferGeometry args={[4, 0.1, 60]} />
          <meshPhysicalMaterial
            color={"green"}
            roughness={0.5}
            transmission={0.5}
          />
        </mesh>

        <mesh position={[-7, 0, -6]} receiveShadow>
          <boxBufferGeometry args={[8, 0.1, 8]} />
          <meshPhysicalMaterial color={"grey"} map={texture} roughness={1} />
        </mesh>
        <mesh position={[-7, 0, -15.6]} receiveShadow>
          <boxBufferGeometry args={[8, 0.1, 8]} />
          <meshPhysicalMaterial color={"grey"} map={texture} roughness={1} />
        </mesh>
        <mesh position={[3, 0, -10.75]} receiveShadow>
          <boxBufferGeometry args={[9, 0.1, 17.75]} />
          <meshPhysicalMaterial color={"grey"} map={texture} roughness={1} />
        </mesh>
      </>
    </Canvas>
  );
}

export default Threedire;
